@@ -7,7 +7,7 @@
 sub get_os {
 	print "Operating system ... ";
 
-	local $uname = `uname`;
+	local($uname) = `uname`;
 	chop($uname);
 	$uname =~ tr/a-z/A-Z/;
 
@@ -19,11 +19,11 @@ sub get_lastlog {
 	print "Lastlog ... ";
 
 	if (-e "/var/adm/lastlog") {
-		local $ll = "/var/adm/lastlog";
+		local($ll) = "/var/adm/lastlog";
 	} elsif (-e "/var/log/lastlog") {
-		local $ll = "/var/log/lastlog";
+		local($ll) = "/var/log/lastlog";
 	} else {
-		local $ll = "/var/adm/wtmp";
+		local($ll) = "/var/adm/wtmp";
 	}
 
 	print "$ll\n";
@@ -53,9 +53,9 @@ sub has_shadow {
 	print "Shadow passwords ... ";
 
 	if (-e "/etc/shadow") {
-		local $shad = "Y";
+		local($shad) = "Y";
 	} else {
-		local $shad = "N";
+		local($shad) = "N";
 	}
 
 	print (($shad eq "Y") ? "/etc/shadow\n" : "No shadow\n");
