@@ -9,18 +9,18 @@ sub get_fqdn {
 
 	&disp_file($config);
 
-	local $hostname = `hostname`;
+	local($hostname) = `hostname`;
 	chop($hostname);
 
-	local $domainname = `domainname`;
+	local($domainname) = `domainname`;
 	chop($domainname);
 
 	if (($hostname ne "(none)") && ($domainname ne "(none)")) {
-		local $fqdn = $hostname . "." . $domainname;
+		local($fqdn) = $hostname . "." . $domainname;
 	} elsif ($hostname eq "(none)") {
-		local $fqdn = $domainname;
+		local($fqdn) = $domainname;
 	} elsif ($domainname eq "(none)") {
-		local $fqdn = $hostname;
+		local($fqdn) = $hostname;
 	}
 
 	$fqdn = &ask_question($question, $fqdn, STRING_QUESTION);
