@@ -83,6 +83,8 @@ TYPEVAL internal_config[] = {
 	{ "ALLOW_USERLOG", SHOW_USERLOG, 3 },
 	{ "ALLOW_EXECUTION", SHOW_EXEC, 3 },
 	{ "ALLOW_FAKEUSER_FINGER", SHOW_FAKEUSER, 3 },
+	{ "ONLY_SHOW_HEADERS_IF_FILE_EXISTS", SHOW_HEADERS_FE, 3 },
+	{ "ONLY_CREATE_FINGERLOG_IF_FILE_EXISTS", SHOW_CREATE_FLG, 3 },
 	{ NULL, 0, 0 }
 };
 
@@ -190,7 +192,7 @@ void do_files(char *str)
 	fscanf(file, "%[^\r\n]\r\n", line);
 	if (!(strncmp(line, "}", 1)))
 	    done++;
-	else {
+	else if (line[0] != '#') {
 	    if (type == DISPLAY_FILES) {
 		char *element, *filename;
 
@@ -235,6 +237,8 @@ void do_files(char *str)
 		    strmcpy(&prog_config.rejected_file, (char *) filename);
 		else if (!(strncasecmp(element, "USERLOG", 7)))
 		    strmcpy(&prog_config.userlog_file, (char *) filename);
+		else if (!(strncasecmp(element, "MAILBOX", 7)))
+		    strmcpy(&prog_config.mailbox_file, (char *) filename);
 		else if (element[0] == '#') {
 		    /* Ignore commented out lines */
 		} else {
@@ -247,22 +251,24 @@ void do_files(char *str)
 	    } else if (type == FINGER_PROGRAMS) {
 		char *element, *filename;
 
-		element = (char *) malloc(80);
-		filename = (char *) malloc(80);
+		if (line[0] != '#') {
+		    element = (char *) malloc(80);
+		    filename = (char *) malloc(80);
 
-		sscanf(line, "\t%[^\t]\t= \"%[^\",]\",\r\n", element, filename);
+		    sscanf(line, "\t%[^\t]\t= \"%[^\",]\",\r\n", element, filename);
 
-		if (!(strncasecmp(element, "FINGER", 6)))
-		    strmcpy(&prog_config.finger_program, (char *) filename);
-		else if (!(strncasecmp(element, "WHOIS", 5)))
-		    strmcpy(&prog_config.whois_program, (char *) filename);
-		else {
-		    errors++;
-		    printf("Option %s unknown in finger_programs.\n", element);
+		    if (!(strncasecmp(element, "FINGER", 6)))
+			strmcpy(&prog_config.finger_program, (char *) filename);
+		    else if (!(strncasecmp(element, "WHOIS", 5)))
+			strmcpy(&prog_config.whois_program, (char *) filename);
+		    else {
+			errors++;
+			printf("Option %s unknown in finger_programs.\n", element);
+		    }
+
+		    free(element);
+		    free(filename);
 		}
-
-		free(element);
-		free(filename);
 	    } else if (type == FINGER_FAKEUSERS) {
 		char *element, *fakename, *boolean, *filename;
 
@@ -355,7 +361,7 @@ void do_hosts(char *str)
 	fscanf(file, "%[^\r\n]\r\n", line);
 	if (!(strncmp(line, "}", 1)))
 	    done++;
-	else {
+	else if (line[0] != '#') {
 	    char *host;
 
 	    host = (char *) malloc(80);
@@ -417,7 +423,7 @@ void do_config(char *str)
 	fgets(line, 80, file);
 	if (!(strncmp(line, "}", 1)))
 	    done++;
-	else {
+	else if (line[0] != '#') {
 	    if (type == FINGER_DISPLAY) {
 		char *element, *opt1, *opt2, *opt3;
 		int x, found = FALSE;
@@ -753,4 +759,9 @@ void check_blank_configurations(void)
 	sprintf(prog_config.finger_sites[num_finger_sites], "localhost");
 	num_finger_sites = 1;
     }
+
+    if (prog_config.mailbox_file == NULL) {
+	prog_config.mailbox_file = (char *) malloc(17);
+	sprintf(prog_config.mailbox_file, "/usr/spool/mail/$USER");
+    }
 }
