@@ -122,7 +122,7 @@ void handle_fakeuser(char *username)
 	    else
 		sprintf(send_string, "%s", prog_config.fusers[funum].script);
 
-	    system(send_string);
+	    safe_exec(send_string);
 	    fflush(stdout);
 	}
     } else {
