@@ -1,4 +1,10 @@
-void setutent();
-struct utmp *getutent();  /* returns next utmp file entry   */
-char *getdomainname(char *, size_t);
+#ifndef __GETUTENT_H__
+#define __GETUTENT_H__
 
+#ifdef BSD
+struct utmp *getutent();  /* returns next utmp file entry   */
+void setutent();
+char *getdomainname(char *, size_t);
+#endif
+
+#endif
