@@ -86,7 +86,7 @@ void handle_internal(char *username)
 	exit(PROGRAM_OKAY);
     } else if (!strncmp(username, "userlist-only", 13)) {
 	if (prog_config.config_bits2 & SHOW_ULISTONLY) {
-	    system("userlist | tail +2");
+	    safe_exec("userlist | tail +2");
 	    fflush(stdout);
 	}
 	log(LOG_USER, "Userlist-only", " ");
