@@ -14,6 +14,7 @@
  */
 
 #include "cfingerd.h"
+#include "proto.h"
 #include "privs.h"
 
 void log(int logtype, char *msg, char *user)
@@ -42,14 +43,28 @@ void log(int logtype, char *msg, char *user)
 
 void userlog(uid_t uid, gid_t gid, char *dir, char *user)
 {
-    FILE *file;
+    FILE *file = NULL;
     char filename[80];
 
     bzero(filename, 80);
     sprintf(filename, "%s/%s", dir, prog_config.userlog_file);
 
+    printf("Userlog\n");
+    fflush(stdout);
+
     USER_PRIVS(uid,gid)
-    file = fopen(filename, "a+");
+
+    /*
+     * If the file doesn't already exist, check to make sure we can
+     * create it (if the sysadmin allows it).  If the file was created,
+     * then they want a finger log, and thus, should show the log here.
+     */
+    if (!exist(filename)) {
+	if (!(prog_config.config_bits3 & SHOW_CREATE_FLG))
+	    file = fopen(filename, "a+");
+    } else
+	file = fopen(filename, "a+");
+
     NOBODY_PRIVS
 
     if (file) {
@@ -59,7 +74,9 @@ void userlog(uid_t uid, gid_t gid, char *dir, char *user)
 	fflush(file);
 	fclose(file);
     } else {
-	syslog(LOG_WARNING, "Userlog: %s (%s)", filename, strerror(errno));
-	log(LOG_ERROR, "Cannot write to userlog: ", strerror(errno));
+	if (!(prog_config.config_bits3 & SHOW_CREATE_FLG)) {
+	    syslog(LOG_WARNING, "Userlog: %s (%s)", filename, strerror(errno));
+	    log(LOG_ERROR, "Cannot write to userlog: ", strerror(errno));
+	}
     }
 }
