@@ -21,7 +21,9 @@
 
 CONFIG prog_config;
 char *remote_addr, *localhost, *ident_user, *ip_address;
-BOOL local_finger, emulated;
+FILE *top_display, *bottom_display, *noname_display, *nouser_display,
+     *identd_display;
+BOOL local_finger, emulated; 
 int local_port, remote_port;
 
 /*
@@ -54,10 +56,8 @@ int main(int argc, char *argv[])
     char username[100], syslog_str[200];
     int un_type;
     char *cp;
-    int nice_res;
 
     /* Initialize CFINGERD */
-    RELINQUISH_PRIVS
     start_handler();
     start_cfingerd();
 
@@ -77,16 +77,18 @@ int main(int argc, char *argv[])
     read_configuration();
     check_blank_configurations();
     check_stats();
+    open_initial_files();
 
-    /* Change program priority to highest priority when running */
-    PRIV_ROOT_START
-    nice_res = nice(-20);
-    PRIV_ROOT_END
-    if (nice_res == -1) {
-	syslog(LOG_ERR, "%s", prog_config.p_strings[D_NICE_FATAL]);
-	log(LOG_ERROR, "Fatal on nice: ", strerror(errno));
-	exit(0);
-    }
+    /*
+     * Okay, now that all of the standard processing has taken place, we
+     * can switch to the NOBODY UID/GID and run everything else as nobody
+     * (to a certain degree.)  Remembering, of course, if we must switch
+     * to a user that's being fingered, we MUST call "RELINQUISH_PRIVS"
+     * to relinquish the root privileges, then call BECOME_USER(UID,GID)
+     * to obtain privileges as that user.  (Read the FAQ for more info.)
+     */
+
+    NOBODY_PRIVS;
 
     /* Make sure there is actually data waiting in the finger port */
     if (!emulated) {
@@ -151,9 +153,10 @@ int main(int argc, char *argv[])
 	} else
 	    remote_addr = (char *) host_ent->h_name;
 
-	for (cp=remote_addr; *cp; cp++)
+	/* Convert any uppercase letters in the hostname to lowercase */
+	for (cp = remote_addr; *cp; cp++)
 	    if (isupper(*cp))
-		*cp = tolower (*cp);
+		*cp = tolower(*cp);
 
 	/* And find out if this is a local finger */
 	if (!strncasecmp(remote_addr, "127.0.0.1", 9) ||
