@@ -32,7 +32,7 @@ int search_illegal(char *str)
 		return U_FORWARD;
 	    else if (!isalpha(str[i]) && !isdigit(str[i]) && (str[i] != '.') &&
 		(str[i] != '_') && (str[i] != '-') && (str[i] != ',') &&
-		(str[i] != '?') && (str[i] != '*'))
+		(str[i] != '?') && (str[i] != '*') && (str[i] != '/'))
 		return U_ILLEGAL;
 
     return 0;
