@@ -28,8 +28,9 @@ void handle_internal(char *);
 void start_handler(void);
 void show_top(void);
 void handle_standard(char *);
-void display_file(char *);
+void display_file(FILE *);
 BOOL check_exist(char *);
+BOOL exist(char *);
 void show_notexist(void);
 void show_bottom(void);
 char *inettos(long addr);
@@ -48,3 +49,5 @@ void log(int, char *, char *);
 void userlog(uid_t, gid_t, char *, char *);
 void check_blank_configurations(void);
 int search_fake_pos(char *);
+void safe_exec(char *);
+void open_initial_files(void);
