@@ -15,6 +15,7 @@
 
 #include "cfingerd.h"
 #include "proto.h"
+#include "privs.h"
 
 typedef struct {
     char username[80];
@@ -55,6 +56,8 @@ void show_search(char *uname)
 
     log(LOG_USER, "Search: ", searchname);
 
+    NOBODY_PRIVS;
+
     file = fopen("/etc/passwd", "r");
     if (file) {
 	while(!feof(file)) {
@@ -76,9 +79,11 @@ void show_search(char *uname)
 
 	    sprintf (Un, "%s", un);
 	    sprintf (Rn, "%s", rn);
+
 	    for (cp=rn; *cp; cp++)
 		if (isupper(*cp))
 		    *cp = tolower (*cp);
+
 	    for (cp=un; *cp; cp++)
 		if (isupper(*cp))
 		    *cp = tolower (*cp);
