@@ -34,7 +34,7 @@ typedef struct {
 } TTY_FROM;
 
 TTY_FROM tty_list[20];
-static int uid;
+static int uid, nuid, ngid; 
 
 /*
  * DO_COLUMNS
@@ -50,63 +50,26 @@ void do_columns(void)
     }
 }
 
-/*
- * PARSE_MODE
- *
- * Check the mode of the file specified by checking it against the mode
- * string.  This simply checks the first bit on the LS file line (see
- * ls -al) and checks to make sure it isn't a non-normal file.
- */
-int parse_mode(char *mode_str)
-{
-    switch(mode_str[0]) {
-	case LS_DIRECTORY:	return(1);
-	case LS_LINK:		return(2);
-	case LS_CHARDEV:	return(3);
-	case LS_BLOCKDEV:	return(4);
-	case LS_SOCKET:		return(5);
-	case LS_FIFO:		return(6);
-	case LS_NORMAL:		return(0);
-    }
-
-    return(0);
-}
-
 /*
  * CHECK_ILLEGAL
  *
- * Check to make sure that the specified .nofinger file given for the user 
+ * Check to make sure that the specified file given for the user 
  * isn't an illegal file.
  */
 BOOL check_illegal(char *str, char *user)
 {
-    char mode[20];
-    int filemode;
+    struct stat statbuf;
 
-    sscanf(str, "%[^\t ]\t %*[^\r\n]\r\n", mode);
+    if ((lstat(str, (struct stat *) &statbuf)) < 0)
+	return(FALSE);
 
-    filemode = parse_mode((char *) mode);
+    if (S_ISREG(statbuf.st_mode))
+	return(FALSE);
+    else
+	syslog(LOG_NOTICE, "%s's file %s is NOT A REGULAR FILE.",
+		user, str);
 
-    if (filemode > 0) {
-	switch(filemode) {
-	    case 1: syslog(LOG_NOTICE, "%s's .nofinger = directory", user);
-		    break;
-	    case 2: syslog(LOG_NOTICE, "%s's .nofinger = symlink", user);
-		    break;
-	    case 3: syslog(LOG_NOTICE, "%s's .nofinger = char device", user);
-		    break;
-	    case 4: syslog(LOG_NOTICE, "%s's .nofinger = block device", user);
-		    break;
-	    case 5: syslog(LOG_NOTICE, "%s's .nofinger = socket", user);
-		    break;
-	    case 6: syslog(LOG_NOTICE, "%s's .nofinger = FIFO", user);
-		    break;
-	}
-
-	return(TRUE);
-    }
-
-    return(FALSE);
+    return(TRUE);
 }
 
 /*
@@ -175,31 +138,35 @@ void show_pfile(int t1, int t2, int t3, char *dir, char *disp, BOOL send_ret)
     if (can_show) {
 	char d[128];
 
-	printf("%s\n", prog_config.p_strings[t2]);
-	fflush(stdout);
-
+	bzero(d, 128);
 	sprintf(d, "%s/%s", dir, disp);
 
+	if (!(prog_config.config_bits3 & SHOW_HEADERS_FE)) {
+	    printf("%s\n", prog_config.p_strings[t2]);
+	    fflush(stdout);
+	}
+
 	if (exist(d)) {
-	    FILE *fil;
-	    char f[80], *s;
+	    NOBODY_PRIVS;
 
-	    sprintf(f, "ls -al %s", d);
-	    fil = popen(f, "r");
-
-	    s = malloc(80);
-
-	    if (fil) {
-		fscanf(fil, "%[^\r\n]\r\n", s);
-		if (!check_illegal(s, "CFINGERD"))
-		    display_file(d);
-
-		pclose(fil);
+	    if (prog_config.config_bits3 & SHOW_HEADERS_FE) {
+		printf("%s\n", prog_config.p_strings[t2]);
+		fflush(stdout);
 	    }
 
-	    free(s);
-	} else
-	    printf("%s\n", prog_config.p_strings[t3]);
+	    if (!check_illegal(d, "CFINGERD")) {
+		FILE *file;
+
+		file = fopen(d, "r");
+		display_file(file);
+		fclose(file);
+	    }
+	} else {
+	    if (!(prog_config.config_bits3 & SHOW_HEADERS_FE))
+		printf("%s\n", prog_config.p_strings[t3]);
+	    else
+		send_ret = 0;
+	}
     }
 
     if (send_ret)
@@ -227,31 +194,32 @@ void show_pfile2(int t1, int t2, int t3, char *dir, char *disp, BOOL send_ret)
     if (can_show) {
 	char d[128];
 
-	printf("%s\n", prog_config.p_strings[t2]);
-	fflush(stdout);
-
 	sprintf(d, "%s/%s", dir, disp);
 
+	if (!(prog_config.config_bits3 & SHOW_HEADERS_FE)) {
+	    printf("%s\n", prog_config.p_strings[t2]);
+	    fflush(stdout);
+	}
+
 	if (exist(d)) {
-	    FILE *fil;
-	    char f[80], *s;
+	    NOBODY_PRIVS;
 
-	    sprintf(f, "ls -al %s", d);
-	    fil = popen(f, "r");
-
-	    s = malloc(80);
-
-	    if (fil) {
-		fscanf(fil, "%[^\r\n]\r\n", s);
-		if (!check_illegal(s, "CFINGERD"))
-		    display_file(d);
-
-		pclose(fil);
+	    if (prog_config.config_bits3 & SHOW_HEADERS_FE) {
+		printf("%s\n", prog_config.p_strings[t2]);
+		fflush(stdout);
 	    }
 
-	    free(s);
-	} else
-	    printf("%s\n", prog_config.p_strings[t3]);
+	    if (!check_illegal(d, "CFINGERD")) {
+		FILE *file;
+
+		file = fopen(d, "r");
+		display_file(file);
+		fclose(file);
+	    }
+	} else {
+	    if (!(prog_config.config_bits3 & SHOW_HEADERS_FE))
+		printf("%s\n", prog_config.p_strings[t3]);
+	}
     }
 
     if (send_ret)
@@ -277,6 +245,7 @@ void show_lasttime_on(char *user)
 
     TTY_FROM last_tty;
 
+    NOBODY_PRIVS;
     fd = open(WTMPFILE, O_RDONLY);
 
 #ifndef	USE_LASTLOG
@@ -357,6 +326,8 @@ void show_not_online(char *user)
 {
     BOOL can_show = FALSE, can_show_lasttime = FALSE;
 
+    NOBODY_PRIVS;
+
     if (local_finger) {
 	if (prog_config.local_config_bits1 & SHOW_IFON)
 	    can_show = TRUE;
@@ -397,10 +368,12 @@ void show_idle(char *tty)
     char dev_file[80];
 
     sprintf(dev_file, "/dev/%s", tty);
-    
-    stat((char *) dev_file, &buf);
-    cur_time = time(NULL);
 
+    USER_PRIVS(nuid, ngid);
+    stat((char *) dev_file, &buf);
+    NOBODY_PRIVS;
+
+    cur_time = time(NULL);
     diff_time = (long) cur_time - (long) buf.st_mtime;
 
     sec = min = hour = day = has = 0;
@@ -467,6 +440,8 @@ void show_times_on(void)
     int i;
     BOOL can_show = FALSE, can_show_orig = FALSE;
 
+    NOBODY_PRIVS;
+
     if (local_finger) {
 	if (prog_config.local_config_bits1 & SHOW_IFON)
 	    can_show = TRUE;
@@ -544,7 +519,10 @@ void show_login_stats(char *user)
 		strcpy(tty_list[times_on].tty, (char *) ut->ut_line);
 
 		sprintf(devfile, "/dev/%s", (char *) ut->ut_line);
+
+		USER_PRIVS(nuid, ngid);
 		stat(devfile, &buf);
+		NOBODY_PRIVS;
 
 		if ((buf.st_mode & S_IWGRP) && (buf.st_mode & S_IWOTH))
 		    tty_list[times_on].writable = TRUE;
@@ -612,7 +590,10 @@ void show_mail_stats(char *user)
 	int fm;
 
 	sprintf(mailfile, "%s/%s", MAIL_SPOOL_DIR, user);
+
+	USER_PRIVS(nuid, ngid);
 	fm = stat(mailfile, &buf);
+	NOBODY_PRIVS;
 
 	if (fm != -1) {
 	    if (can_show_date)
@@ -651,7 +632,6 @@ void show_fingerinfo(char *user)
     FILE *file;
     char username[80], room[80], work_phone[80], home_phone[80],
 	 other[80], fn[80];
-    int nuid, ngid;
 
     columns = 0;
     pwent = getpwnam(user);
@@ -674,31 +654,20 @@ void show_fingerinfo(char *user)
     sprintf(fn, "%s/.nofinger", pwent->pw_dir);
 
     if (exist(fn)) {
-	FILE *fil;
-	char f[80], *s;
-
-	sprintf(f, "ls -al %s", fn);
-	fil = popen(f, "r");
-
-	s = malloc(80);
-
-	if (fil) {
-	    fscanf(fil, "%[^\r\n]\r\n", s);
-	    if (check_illegal((char *) s, user)) {
-		show_bottom();
-		exit(PROGRAM_SYSLOG);
-	    }
-
-	    pclose(fil);
+	if (!check_illegal((char *) fn, user)) {
+	    show_bottom();
+	    exit(PROGRAM_SYSLOG);
 	}
-
-	free(s);
     }
 
+    USER_PRIVS(nuid, ngid);
     if ((file = fopen(fn, "r")) != NULL) {
+	NOBODY_PRIVS;
+	display_file(file);
 	fclose(file);
-	display_file((char *) fn);
     } else {
+	NOBODY_PRIVS;
+
 	show_stuff(user, SHOW_UNAME, D_USERNAME);
 	show_stuff(username, SHOW_REALNAME, D_REALNAME);
 	show_stuff(pwent->pw_dir, SHOW_DIR, D_DIRECTORY);
@@ -728,9 +697,6 @@ void show_fingerinfo(char *user)
 	/* I made a typo here ... thanks to stig@hackvan.com, it was
 	   corrected. */
 
-	/* User priviledges patch thanks to Dan Hollis */
-	USER_PRIVS(nuid,ngid)
-
 	show_pfile(SHOW_PROJECT, D_PROJECT, D_NO_PROJECT, pwent->pw_dir, 
 		prog_config.project_file, 
 	(prog_config.config_bits2 & SHOW_STRICTFMT) ? FALSE : TRUE);
@@ -746,8 +712,6 @@ void show_fingerinfo(char *user)
 
 	show_pfile2(SHOW_XFACE, D_XFACE, D_NO_XFACE, pwent->pw_dir,
 		prog_config.xface_file, FALSE);
-
-	RELINQUISH_PRIVS
     }
 }
 
@@ -762,6 +726,18 @@ void handle_standard(char *username)
     char uname[600];
     int nums = 0;
 
+    /*
+    ** Support to change the "/W" or "-L" listings from Microsoft's
+    ** bloated finger program.  This combats their options, and ignores
+    ** them.
+    **
+    ** Ken Hollis 08/06/96
+    */
+    if (username[0] == '/')
+	strcpy(username, username + 2);
+    else if (username[0] == '-')
+	strcpy(username, username + 2);
+
     if ((!(prog_config.config_bits2 & SHOW_FINGERFWD)) || 
 	check_exist(username))
 	show_top();
@@ -773,7 +749,7 @@ void handle_standard(char *username)
 		printf("\nChecking site %s for the specified user.\n", prog_config.forward[nums]);
 		fflush(stdout);
 		sprintf(uname, "finger %s\100%s | tail +2", username, prog_config.forward[nums]);
-		system(uname);
+		safe_exec(uname);
 		nums++;
 		log(LOG_USER, "Forwarded: ", username);
 	    }
@@ -786,6 +762,7 @@ void handle_standard(char *username)
     }
 
     if ((!(prog_config.config_bits2 & SHOW_FINGERFWD)) || 
-	check_exist(username))
+	check_exist(username)) {
 	show_bottom();
+    }
 }
