@@ -38,11 +38,7 @@ void handle_userlist(void)
 
     if (can_show) {
 	int i;
-	char fslist_name[32], sslist_name[32], cmdline[128];
-
-	sprintf(fslist_name, "/tmp/fslist.%d", getpid());
-	strcpy(sslist_name, fslist_name);
-	strcat(sslist_name, ".sort");
+	char cmdline[128];
 
 	if ((num_finger_sites > 1) &&
 	    prog_config.config_bits2 & SHOW_MULTFING) {
@@ -50,9 +46,13 @@ void handle_userlist(void)
 	    fflush(stdout);
 	}
 
-	PRIV_ROOT_START
-	(void) unlink(fslist_name);
-	PRIV_ROOT_END
+	NOBODY_PRIVS;
+
+	if ((!strstr(prog_config.finger_program, "finger")) &&
+	    (!strstr(prog_config.finger_program, "w"))) {
+	    printf("Username Real name                      Idletime TTY Remote console location\n");
+	    fflush(stdout);
+	}
 
 	if (prog_config.config_bits2 & SHOW_MULTFING) {
 	    for (i = 0; i < num_finger_sites; i++) {
@@ -63,21 +63,16 @@ void handle_userlist(void)
 			printf("cfingerd could not allocate memory for the userlist program!\n");
 			fflush(stdout);
 		    } else {
-			sprintf(st, "%s | tail +2 >> %s",
-			    prog_config.finger_program, fslist_name);
+			sprintf(st, "%s | tail +2", prog_config.finger_program);
 
-			PRIV_ROOT_START
-			system(st);
+			safe_exec(st);
 			free(st);
-			PRIV_ROOT_END
 		    }
 		} else {
-		    sprintf(cmdline, "finger userlist-only@%s | tail +3 >> %s",
-			prog_config.finger_sites[i], fslist_name);
+		    sprintf(cmdline, "finger userlist-only@%s | tail +3",
+			prog_config.finger_sites[i]);
 
-		    PRIV_ROOT_START
-		    system(cmdline);
-		    PRIV_ROOT_END
+		    safe_exec(cmdline);
 		}
 	    }
 	} else {
@@ -85,35 +80,18 @@ void handle_userlist(void)
 
 	    if ((!strstr(prog_config.finger_program, "finger")) &&
 		(!strstr(prog_config.finger_program, "w")))
-		sprintf(st, "%s | tail +2 >> %s",
-		    prog_config.finger_program, fslist_name);
+		sprintf(st, "%s | tail +2", prog_config.finger_program);
 	    else 
-		sprintf(st, "%s >> %s",
-		    prog_config.finger_program, fslist_name);
+		sprintf(st, "%s", prog_config.finger_program);
 
-	    PRIV_ROOT_START
-	    system(st);
-	    PRIV_ROOT_END
+	    safe_exec(st);
 	}
 
-	PRIV_ROOT_START
-	sprintf(cmdline, "sort <%s >%s", fslist_name, sslist_name);
-	system(cmdline);
-	unlink(fslist_name);
-	PRIV_ROOT_END
-
 	if ((num_finger_sites > 1) &&
 	    prog_config.config_bits2 & SHOW_MULTFING)
 	    printf("\n**> This is the complete listing of %d sites total.\n\n",
 		    num_finger_sites);
 
-	if ((!strstr(prog_config.finger_program, "finger")) &&
-	    (!strstr(prog_config.finger_program, "w"))) {
-	    printf("Username Real name                      Idletime TTY Remote console location\n");
-	    fflush(stdout);
-	    display_file(sslist_name);
-	}
-
 	if ((num_finger_sites > 1) &&
 	    prog_config.config_bits2 & SHOW_MULTFING)
 	    SEND_RAW_RETURN;
@@ -122,15 +100,8 @@ void handle_userlist(void)
 
 	if ((num_finger_sites > 1) &&
 	    prog_config.config_bits2 & SHOW_MULTFING) {
-		char cmd[80];
-
-		sprintf(cmd, "echo \"There are `wc --lines <%s` usersonline.\"", sslist_name);
-		system(cmd);
+		printf("*** This is a list of %dsystems.\n",num_finger_sites);
 	    }
-
-	PRIV_ROOT_START
-	unlink(sslist_name);
-	PRIV_ROOT_END
     } else {
 	can_show = FALSE;
 
@@ -143,7 +114,7 @@ void handle_userlist(void)
 	}
 
 	if (can_show)
-	    display_file(prog_config.no_name_banner_file);
+	    display_file(noname_display);
     }
 
     show_bottom();
