@@ -297,18 +297,13 @@ void parse_line(char *line)
  *
  * This displays the file specified.
  */
-void display_file(char *filename)
+void display_file(FILE *file_ent)
 {
-    FILE *file;
     char line[128];
     int bsize = sizeof(line);
 
-    PRIV_ROOT_START
-    file = fopen(filename, "r");
-    PRIV_ROOT_END
-
-    if (file) {
-	while(fgets(line, bsize, file)) {
+    if (file_ent) {
+	while(fgets(line, bsize, file_ent)) {
 	    if (prog_config.config_bits3 & SHOW_PARSING)
 		parse_line(line);
 	    else
@@ -316,9 +311,8 @@ void display_file(char *filename)
 	}
 
 	fflush(stdout);
-	fclose(file);
-    } else
-	syslog(LOG_ERR, "Cannot open %s!", filename);
+	fclose(file_ent);
+    }
 }
 
 /* 
@@ -339,7 +333,7 @@ void show_top(void)
     }
 
     if (can_show)
-	display_file(prog_config.top_display_file);
+	display_file(top_display);
 }
 
 /*
@@ -373,7 +367,7 @@ void show_notexist(void)
     }
 
     if (can_show)
-	display_file(prog_config.no_user_banner_file);
+	display_file(nouser_display);
 }
 
 /* 
@@ -394,7 +388,7 @@ void show_bottom(void)
     }
 
     if (can_show)
-	display_file(prog_config.bottom_display_file);
+	display_file(bottom_display);
 }
 
 /*
@@ -450,8 +444,8 @@ void check_unknown(char *host)
 	(wildmat(ident_user, "unknown@*"))) {
 	syslog(LOG_NOTICE, "Finger from %s %s",
 	    host, prog_config.p_strings[D_REJECT_HOST]);
-	if (prog_config.config_bits2 & SHOW_REJECTED)
-	    display_file(prog_config.rejected_file);
+/*	if (prog_config.config_bits2 & SHOW_REJECTED)
+	    display_file(prog_config.rejected_file); */
 
 	log(LOG_IDENT, "Unknown not allowed from ", host);
 
@@ -504,11 +498,79 @@ void check_rejected(char *host)
 	    (wildmat(ip_address, prog_config.rejected[i]))) {
 	    syslog(LOG_NOTICE, "Finger from %s %s",
 		host, prog_config.p_strings[D_REJECT_HOST]);
-	    if (prog_config.config_bits2 & SHOW_REJECTED)
-		display_file(prog_config.rejected_file);
+/*	    if (prog_config.config_bits2 & SHOW_REJECTED)
+		display_file(prog_config.rejected_file); */
 
 	    log(LOG_REJECTED, "Rejected host finger detected to ", host);
 
 	    exit(PROGRAM_OKAY);
 	}
 }
+
+/*
+ * SAFE_EXEC
+ *
+ * This is a safe version of the "system", "exec" or "popen" command.  This
+ * simply takes on the UID/GID of the NOBODY (or apparent NOBODY) UID/GID,
+ * and runs the specified program as that user.  If it ever fails, it will
+ * display in syslog the reason WHY it failed, along with a semi-detailed
+ * message of the failure.
+ */
+void safe_exec(char *cmd)
+{
+    FILE *file;
+    char line[600];
+
+#ifdef	NOBODY_UID
+#ifdef	NOBODY_GID
+    NOBODY_PRIVS;
+
+    file = popen(cmd, "r");
+
+    if (file) {
+	while(!feof(file)) {
+	    bzero(line, 600);
+	    fgets(line, 600, file);
+	    printf("%s", line);
+	    fflush(stdout);
+	}
+    } else {
+	syslog(LOG_ERR, "With the nobody UID/GID set,");
+	syslog(LOG_ERR, "safe_exec failed on %s: %s", cmd, strerror(errno));
+    }
+
+    RELINQUISH_PRIVS;
+#else
+    syslog(LOG_ERR, "No GID for Nobody defined.");
+#endif
+#else
+    syslog(LOG_ERR, "No UID for Nobody defined.");
+#endif
+}
+
+/*
+ * MY_FOPEN
+ *
+ * Quick way to open files and check for errors at the same time.
+ */
+FILE *my_fopen(char *filename)
+{
+    FILE *myfile;
+
+    myfile = fopen(filename, "r");
+    return myfile;
+}
+
+/*
+ * OPEN_INITIAL_FILES
+ *
+ * This safely opens all files that are specified at startup.  This allows
+ * the files to be read, after they have been opened with root access.
+ */
+void open_initial_files(void)
+{
+    top_display = my_fopen(prog_config.top_display_file);
+    bottom_display = my_fopen(prog_config.bottom_display_file);
+    noname_display = my_fopen(prog_config.no_name_banner_file);
+    nouser_display = my_fopen(prog_config.no_user_banner_file);
+}
