@@ -31,7 +31,7 @@ char *get_localhost(void)
     bzero(hostname, 80);
 
     gethostname((char *) hostname, (size_t) 80);
-    if (p=index(hostname, '.'))
+    if ((p = index(hostname, '.')) != NULL)
       *p = '\0';
 
     ret = (char *) malloc(strlen((char *) hostname) + 1);
