@@ -19,6 +19,9 @@ void show_idle(char *tty)
     char idledisp[80];
     char dev_file[80];
 
+    bzero(idledisp, 80);
+    bzero(dev_file, 80);
+
     sprintf(dev_file, "/dev/%s", tty);
 
     stat((char *) dev_file, &buf);
